#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# require 'hardware_information/monitor/monitor.rb'
# HardwareInformation.return_the_monitor_resolution
# =========================================================================== #
class HardwareInformation

  # ========================================================================= #
  # === HardwareInformation.return_the_monitor_resolution
  #
  # This method essentially captures the resolution from a String
  # such as:
  #
  #   dimensions:    1920x1080 pixels (508x285 millimeters)
  #
  # It will then return a String, as result, such as "1920x1080".
  # ========================================================================= #
  def self.return_the_monitor_resolution
    result = `xdpyinfo`.split("\n").select {|entry| entry.include? 'dimensions' }
    if result.is_a? Array
      result = result.first
    end
    result.strip!
    if result.include? 'x'
      result = result.scan(/(\d{2,4}x\d{2,4})/).flatten.first.strip
    end
    return result
  end

end

if __FILE__ == $PROGRAM_NAME
  puts HardwareInformation.return_the_monitor_resolution
end